#
# spec file for package shairport-sync
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           shairport-sync
Version:        3.2.2
Release:        2.1
Summary:        An AirPlay audio player
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/mikebrady/shairport-sync
Source0:        https://github.com/mikebrady/shairport-sync/archive/%{version}.tar.gz
Source1:        airplay-server.xml
Source2:        README.SUSE
# PATCH-FIX-OPENSUSE drop-user-config.patch hillwood@opensuse.org -- Move configuring user account to rpm spec.
# Move configuring user account to rpm spec.
Patch0:         drop-user-config.patch
BuildRequires:  fdupes
BuildRequires:  firewall-macros
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(libdaemon)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(systemd)
Requires:       firewalld
Requires(pre):  shadow
%{?systemd_ordering}

%description
Shairport Sync is an AirPlay audio player – it plays audio streamed from iTunes,
iOS, Apple TV and macOS devices and AirPlay sources such as Quicktime Player and
ForkedDaapd, among others.

Audio played by a Shairport Sync-powered device stays synchronised with the
source and hence with similar devices playing the same source. In this way,
synchronised multi-room audio is possible for players that support it, such as
iTunes.

Shairport Sync runs on Linux, FreeBSD and OpenBSD. It does not support AirPlay
video or photo streaming.

%prep
%setup -q
%patch0 -p1
cp %{SOURCE2} .

%build
autoreconf -i -f
%configure --with-systemd \
           --with-ssl=openssl \
           --with-pa \
           --with-pipe \
           --with-avahi \
           --with-soxr \
           --with-metadata \
           --with-configfiles \
           --with-convolution
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_libexecdir}/firewalld/services
install -m 0644 %{SOURCE1} %{buildroot}%{_libexecdir}/firewalld/services/
rm %{buildroot}%{_sysconfdir}/shairport-sync.conf.sample
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
getent group %{name} >/dev/null || %{_sbindir}/groupadd --system %{name}
getent passwd %{name} >/dev/null || %{_sbindir}/useradd --system -c "%{name} User" \
        -d %{_localstatedir}/%{name} -m -g %{name} -s %{_sbindir}/nologin \
        -G audio %{name}
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%firewalld_reload

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md RELEASENOTES.md TROUBLESHOOTING.md README.SUSE
%license LICENSES
%config(noreplace) %{_sysconfdir}/shairport-sync.conf
%{_bindir}/%{name}
%dir %{_libexecdir}/firewalld
%dir %{_libexecdir}/firewalld/services
%{_libexecdir}/firewalld/services/airplay-server.xml
%{_mandir}/man7/shairport-sync.7%{?ext_man}
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%changelog
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Transform bash-specific sh code to POSIX sh in scriptlets.
- Do not hide errors from useradd.
- Reduce hard scriptlet dependency on systemd;
  %%service_* does not need it.
* Sun Feb 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Really use upstream tarball from the source url
* Wed Feb  6 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to release 3.2.2
  Version 3.2 introduces two big new features – MPRIS support and a "native" Shairport
  Sync D-Bus interface. MPRIS offers a standard set of facilities for implementing remote
  control and the native D-Bus interface allows local programs to interact
  directly with Shairport Sync.
  When used with either of these interfaces, Shairport Sync offers access
  to the remote control commands available to control the source, and also
  offers access to metadata, including titles and cover art. These new features
  are experimental, but are already useful.
  This release of Shairport Sync contains important bug fixes and stability
  improvements and is recommended for all users. If offers better synchronisation,
  better compatibility with third-party AirPlay sources, greater stability when
  used with YouTube and macOS system sound, faster resynchronisation, better
  performance on noisy or congested networks and many other improvements.
  A quick INSTALL guide for the Raspberry Pi, a how-to CAR INSTALL guide and
  a note about installing to OpenBSD have been added.
- See https://github.com/mikebrady/shairport-sync/releases for details
* Mon Jul 30 2018 jengelh@inai.de
- Avoid repeating name in summary (rpmlint).
* Mon Jun 11 2018 hillwood@opensuse.org
- Initial package for 3.2rc10.
- Add drop-user-config.patch, move configuring user account to rpm spec.
- Add firewalld profile.
- Add README.SUSE
